@@ -1,9 +1,7 @@
 """PyVista package for 3D plotting and mesh analysis."""
 import warnings
 import os
-import sys
 import appdirs
-
 from pyvista._version import __version__
 from pyvista.plotting import *
 from pyvista.utilities import *
@@ -19,7 +17,6 @@ if VTK_ID_TYPE_SIZE == 4:
 elif VTK_ID_TYPE_SIZE == 8:
     ID_TYPE = np.int64
 
-
 # for additional error output for VTK segfaults
 try:
     import faulthandler
@@ -44,12 +41,11 @@ except KeyError:
     pass
 
 # flag for when building the sphinx_gallery
-BUILDING_GALLERY = 'sphinx' in sys.modules
+BUILDING_GALLERY = False
 if 'PYVISTA_BUILDING_GALLERY' in os.environ:
     if os.environ['PYVISTA_BUILDING_GALLERY'].lower() == 'true':
         BUILDING_GALLERY = True
 
-
 # Grab system flag for anti-aliasing
 try:
     rcParams['multi_samples'] = int(os.environ['PYVISTA_MULTI_SAMPLES'])
