@@ -61,11 +61,11 @@ class DataObject:
 
         """
         if self._READERS is None:
-            raise NotImplementedError('{} readers are not specified, this should be a' \
+            raise NotImplementedError('{} readers are not specified, this should be a'
                                       ' dict of (file extension: vtkReader type)'
                                       .format(self.__class__.__name__))
 
-        filename = os.path.abspath(os.path.expanduser(filename))
+        filename = os.path.abspath(os.path.expanduser(str(filename)))
         if not os.path.isfile(filename):
             raise FileNotFoundError('File %s does not exist' % filename)
 
@@ -103,7 +103,7 @@ class DataObject:
                                       ' dict of (file extension: vtkWriter type)'
                                       .format(self.__class__.__name__))
 
-        filename = os.path.abspath(os.path.expanduser(filename))
+        filename = os.path.abspath(os.path.expanduser(str(filename)))
         file_ext = fileio.get_ext(filename)
         if file_ext not in self._WRITERS:
             raise ValueError('Invalid file extension for this data type. Must be one of: {}'.format(
@@ -630,7 +630,12 @@ class Common(DataSetFilters, DataObject):
             # use active scalars array
             _, arr = self.active_scalars_info
         if isinstance(arr, str):
-            arr = get_array(self, arr, preference=preference)
+            name = arr
+            # This can return None when an array is not found - expected
+            arr = get_array(self, name, preference=preference)
+            if arr is None:
+                # Raise a value error if fetching the range of an unknown array
+                raise ValueError('Array `{}` not present.'.format(name))
         # If array has no tuples return a NaN range
         if arr is None or arr.size == 0 or not np.issubdtype(arr.dtype, np.number):
             return (np.nan, np.nan)
