@@ -3,6 +3,7 @@
 These classes hold many VTK datasets in one object that can be passed
 to VTK algorithms and PyVista filtering/plotting routines.
 """
+import pathlib
 import collections.abc
 import logging
 
@@ -78,16 +79,22 @@ class MultiBlock(vtkMultiBlockDataSet, CompositeFilters, DataObject):
             elif isinstance(args[0], (list, tuple)):
                 for block in args[0]:
                     self.append(block)
-            elif isinstance(args[0], str):
+            elif isinstance(args[0], (str, pathlib.Path)):
                 self._load_file(args[0])
             elif isinstance(args[0], dict):
                 idx = 0
                 for key, block in args[0].items():
                     self[idx, key] = block
                     idx += 1
+            else:
+                raise TypeError('Type %s is not supported by pyvista.MultiBlock'
+                                % type(args[0]))
 
             # keep a reference of the args
             self.refs.append(args)
+        elif len(args) > 1:
+            raise ValueError('Invalid number of arguments:\n``pyvista.MultiBlock``'
+                             'supports 0 or 1 arguments.')
 
         # Upon creation make sure all nested structures are wrapped
         self.wrap_nested()
@@ -179,14 +186,11 @@ class MultiBlock(vtkMultiBlockDataSet, CompositeFilters, DataObject):
             data = self[i]
             if data is None:
                 continue
-            # get the scalars if available
-            arr = get_array(data, name)
-            if arr is None or not np.issubdtype(arr.dtype, np.number):
-                continue
-            tmi, tma = np.nanmin(arr), np.nanmax(arr)
-            if tmi < mini:
+            # get the scalars if available - recursive
+            tmi, tma = data.get_data_range(name)
+            if not np.isnan(tmi) and tmi < mini:
                 mini = tmi
-            if tma > maxi:
+            if not np.isnan(tma) and tma > maxi:
                 maxi = tma
         return mini, maxi
 
